OiRA

Help

1. Suunnittelu
2. Osallistuminen ja yhteistyö
3. Tunnistaminen + Arviointi
4. Toimintasuunnitelma
5. Raportti
6. Riskinarvioinnin tila 0%

# Muokkaa organisaatiosi riskinarviointia

Organisaatiosi riskinarvioinnin muokkauksen yhteydessä sinulta saatetaan kysyä seuraavaa:

- valitse tai sivuuta tilanteet, jotka ovat tai eivät ole oleellisia liiketoiminnallesi, ja laita rasti ruutuun tarvittaessa
- anna useampi toimintayksikkö, toimiala tai myymälä jne. Nämä riskit toistetaan jokaisen antamasi nimen yhteydessä.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More